Didsho
------
require python 2.7 and later

Didsho is best advertisement bot in telegram with earn money for iranian users. you can found bot in @didshobot

To use (with caution), simply do::

for python 3.5 and later

    >>> from didsho import ads_libs_requests
    >>> ads = ads_libs_requests.Didsho(your_bot_id, your_bot_token)
    >>> ads.send_ads(chat_id)

for python 2.7

    >>> from didsho import ads_libs
    >>> ads = ads_libs.Didsho(your_bot_id, your_bot_token)
    >>> ads.send_ads(chat_id)